#ifndef NewNoteDataUtil_H
#define NewNoteDataUtil_H

#include "GameConstantsAndTypes.h"	// for RadarCategory
#include "NoteTypes.h"
#include "NewNoteData.h"

struct PlayerOptions;

/* Utils for NewNoteData.  Things should go in here if they can be (cleanly and
 * efficiently) implemented using only NewNoteData's primitives; this improves
 * abstraction and makes it much easier to change NewNoteData internally in
 * the future. */
namespace NewNoteDataUtil
{
	NoteType GetSmallestNoteTypeForMeasure( const NewNoteData &n, int iMeasureIndex );
	void LoadFromSMNoteDataString( NewNoteData &out, CString sSMNewNoteData, CString sSMAttackData );
	void GetSMNoteDataString( const NewNoteData &in, CString &notes_out, CString &attacks_out );
	void LoadTransformedLights( const NewNoteData &in, NewNoteData &out, int iNewNumTracks );

	float GetStreamRadarValue( const NewNoteData &in, float fSongSeconds );
	float GetVoltageRadarValue( const NewNoteData &in, float fSongSeconds );
	float GetAirRadarValue( const NewNoteData &in, float fSongSeconds );
	float GetFreezeRadarValue( const NewNoteData &in, float fSongSeconds );
	float GetChaosRadarValue( const NewNoteData &in, float fSongSeconds );

	// radar values - return between 0.0 and 1.2
	float GetRadarValue( const NewNoteData &in, RadarCategory rv, float fSongSeconds );

	void RemoveHoldNotes( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void RemoveSimultaneousNotes( NewNoteData &in, int iMaxSimultaneous, float fStartBeat = 0, float fEndBeat = 99999 );
	void RemoveJumps( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void RemoveHands( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void RemoveQuads( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void RemoveMines( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	enum TrackMapping { left, right, mirror, shuffle, super_shuffle, stomp, NUM_TRACK_MAPPINGS };
	void Turn( NewNoteData &in, StepsType st, TrackMapping tt, float fStartBeat = 0, float fEndBeat = -1 );
	void Little( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Wide( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Big( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Quick( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void BMRize( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Skippy( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void InsertIntelligentTaps( 
		NewNoteData &in, 
		float fWindowSizeBeats, 
		float fInsertOffsetBeats, 
		float fWindowStrideBeats, 
		bool bSkippy, 
		float fStartBeat = 0, 
		float fEndBeat = 99999 );
	void AddMines( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Echo( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Planted( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void Stomp( NewNoteData &in, StepsType st, float fStartBeat = 0, float fEndBeat = 99999 );
	void Twister( NewNoteData &in, float fStartBeat = 0, float fEndBeat = 99999 );
	void ConvertTapsToHolds( NewNoteData &in, int iSimultaneousHolds, float fStartBeat = 0, float fEndBeat = 99999 );

	// change all TAP_ADDITIONs to TAP_TAPs
	void ConvertAdditionsToRegular( NewNoteData &in );

	void Backwards( NewNoteData &in );
	void SwapSides( NewNoteData &in );
	void CopyLeftToRight( NewNoteData &in );
	void CopyRightToLeft( NewNoteData &in );
	void ClearLeft( NewNoteData &in );
	void ClearRight( NewNoteData &in );
	void CollapseToOne( NewNoteData &in );
	void CollapseLeft( NewNoteData &in );
	void ShiftLeft( NewNoteData &in );
	void ShiftRight( NewNoteData &in );

	void SnapToNearestNoteType( NewNoteData &in, NoteType nt1, NoteType nt2, float fBeginBeat, float fEndBeat );

	inline void SnapToNearestNoteType( NewNoteData &in, NoteType nt, float fBeginBeat, float fEndBeat ) { SnapToNearestNoteType( in, nt, (NoteType)-1, fBeginBeat, fEndBeat ); }

	void FixImpossibleRows( NewNoteData &in, StepsType st );

	// True if no notes in row that aren't true in the mask
	bool RowPassesValidMask( NewNoteData &in, int row, const bool bValidMask[] );

	void TransformNewNoteData( NewNoteData &nd, const PlayerOptions &po, StepsType st, float fStartBeat = 0, float fEndBeat = 99999 );
	void AddTapAttacks( NewNoteData &nd, Song* pSong );

	// void Scale( NewNoteData &nd, float fScale );
	void ScaleRegion( NewNoteData &nd, float fScale, float fStartBeat = 0, float fEndBeat = 99999);
	inline void Scale( NewNoteData &nd, float fScale ) { NewNoteDataUtil::ScaleRegion(nd, fScale); }

	// If fBeatsToShift>0, add blank rows.  If fBeatsToShift<0, delete rows
	void ShiftRows( NewNoteData &nd, float fStartBeat, float fBeatsToShift );
};

#endif

/*
 * (c) 2001-2004 Chris Danford, Glenn Maynard
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

