/* Completely standard-issue DirectInput code.  Written by Glenn Maynard; in the
 * public domain. */

#include "global.h"
#include "InputHandler_Test.h"

#include "StepMania.h"
#include "RageUtil.h"
#include "RageLog.h"
#include "SDL_utils.h"
#include "InputFilter.h"


InputHandler_Test::InputHandler_Test()
{
	LOG->Trace( "InputHandler_Test::InputHandler_Test()" );
	
	shutdown = false;
	StartThread();
}

void InputHandler_Test::StartThread()
{
	ASSERT( !InputThread.IsCreated() );
	InputThread.SetName( "DirectInput thread" );
	InputThread.Create( InputThread_Start, this );
}

void InputHandler_Test::ShutdownThread()
{
	if( !InputThread.IsCreated() )
		return;

	shutdown = true;
	LOG->Trace("Shutting down DirectInput thread ...");
	InputThread.Wait();
	LOG->Trace("DirectInput thread shut down.");
	shutdown = false;
}

InputHandler_Test::~InputHandler_Test()
{
	ShutdownThread();
}


void InputHandler_Test::Update(float fDeltaTime)
{
	InputHandler::UpdateTimer();
}

static int RunNetcat()
{
	int fds[2];
	if( pipe(fds) == -1 )
		return -1;

	int pid = fork();
	if( pid == -1 )
	{
		close( fds[0] );
		close( fds[1] );
		return -1;
	}

	if( pid == 0 )
	{
		close( fds[0] );
		close( fileno(stdin) );

		dup2( fds[1], fileno(stdout) );

		for( int i = 3; i < 1024; ++i )
			close( i );
		execlp( "nc", "nc", "-u", "-p", "5959", "-l", NULL );
		_exit(1);
	}

	close( fds[1] );

	return fds[0];
}

#include <sys/poll.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
void InputHandler_Test::InputThreadMain()
{
	int fd = RunNetcat();
	int ret = fcntl( fd, F_SETFL, O_NONBLOCK );
	ASSERT_M( ret != -1, ssprintf(strerror(errno)) );

	while(!shutdown)
	{
		pollfd pfd = { fd, POLLIN, 0 };
		ret = poll( &pfd, 1, 100 );
		switch( ret )
		{
		case 1:
			break;
		case 0:
			continue;
		case -1:
			if( errno != EINTR )
				LOG->Warn( "Error polling: %s", strerror(errno) );
			continue;
		}

		ASSERT_M( pfd.revents & POLLIN, ssprintf("%x", pfd.revents) );

		char buf[1];
		ret = read( fd, buf, 1 );
		LOG->Trace("ret %i", ret);

		RageTimer now;
		ButtonPressed(DeviceInput(DEVICE_JOY1, JOY_1, now), true);
		ButtonPressed(DeviceInput(DEVICE_JOY1, JOY_1, now), false);
	}
}

void InputHandler_Test::GetDevicesAndDescriptions(vector<InputDevice>& vDevicesOut, vector<CString>& vDescriptionsOut)
{
	vDevicesOut.push_back( DEVICE_JOY1 );
	vDescriptionsOut.push_back( "XXX" );
}
